@@ -30,7 +30,7 @@ typedef struct {
 	int  socket;
 #ifdef ENABLE_TLS
 	bool use_tls;
-	mbedtls_ssl_context *tls_context;
+	TLS_context *tls_context;
 #endif
 } t_stream;
 
